@@ -1,6 +1,6 @@
 # coding=utf-8
 """
-uptime.py - Uptime module
+uptime.py - Sopel Uptime Module
 Copyright 2014, Fabian Neundorf
 Licensed under the Eiffel Forum License 2.
 
@@ -8,20 +8,20 @@ https://sopel.chat
 """
 from __future__ import unicode_literals, absolute_import, print_function, division
 
-from sopel.module import commands
 import datetime
 
+from sopel.module import commands
+
 
 def setup(bot):
-    if "uptime" not in bot.memory:
-        bot.memory["uptime"] = datetime.datetime.utcnow()
+    if "start_time" not in bot.memory:
+        bot.memory["start_time"] = datetime.datetime.utcnow()
 
 
 @commands('uptime')
 def uptime(bot, trigger):
     """.uptime - Returns the uptime of Sopel."""
     delta = datetime.timedelta(seconds=round((datetime.datetime.utcnow() -
-                                              bot.memory["uptime"])
+                                              bot.memory["start_time"])
                                              .total_seconds()))
-    bot.say("I've been sitting here for {} and I keep "
-            "going!".format(delta))
+    bot.say("I've been sitting here for {} and I keep going!".format(delta))
